## 4.64.5 (2022-08-18)

Support extras in stubtest_third_party.py (#8467)

## 4.64.4 (2022-07-15)

`tqdm`: Add `__all__` to `__init__.pyi` and submodules (#8308)

Fixes #8307

## 4.64.3 (2022-07-15)

`tqdm`: Improve a few `__init__` methods (#8246)

## 4.64.2 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 4.64.1 (2022-07-07)

Improve `tqdm.contrib.logging` context managers (#8251)

## 4.64.0 (2022-07-05)

Add stubs for `tqdm` (#8235)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>
Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

